@@ -15,6 +15,7 @@ from synology_dsm.api.dsm.network import SynoDSMNetwork
 from synology_dsm.api.photos import SynoPhotos
 from synology_dsm.api.storage.storage import SynoStorage
 from synology_dsm.api.surveillance_station import SynoSurveillanceStation
+from synology_dsm.api.virtual_machine_manager import SynoVirtualMachineManager
 from synology_dsm.const import API_AUTH
 from synology_dsm.exceptions import SynologyDSMLogin2SARequiredException
 
@@ -55,6 +56,7 @@ class TestSynologyDSM7:
         assert isinstance(dsm_7.system, SynoCoreSystem)
         assert isinstance(dsm_7.upgrade, SynoCoreUpgrade)
         assert isinstance(dsm_7.utilisation, SynoCoreUtilization)
+        assert isinstance(dsm_7.virtual_machine_manager, SynoVirtualMachineManager)
 
     @pytest.mark.asyncio
     async def test_login_2sa(self):
@@ -86,6 +88,22 @@ class TestSynologyDSM7:
         assert dsm_7._device_token == DEVICE_TOKEN
         assert dsm_7.device_token == DEVICE_TOKEN
 
+    @pytest.mark.asyncio
+    async def test_information(self, dsm_7):
+        """Test information."""
+        assert await dsm_7.login()
+        assert dsm_7.information
+        await dsm_7.information.update()
+        assert dsm_7.information.model == "DS918+"
+        assert dsm_7.information.ram == 4096
+        assert dsm_7.information.serial == "1920PDN001501"
+        assert dsm_7.information.temperature == 40
+        assert not dsm_7.information.temperature_warn
+        assert dsm_7.information.uptime == 155084
+        assert dsm_7.information.version == "24922"
+        assert dsm_7.information.version_string == "DSM 7.0-41222"
+        assert dsm_7.information.awesome_version == "7.0.0"
+
     @pytest.mark.asyncio
     async def test_external_usb(self, dsm_7):
         """Test external USB storage devices."""
@@ -292,3 +310,127 @@ class TestSynologyDSM7:
         assert items[1].thumbnail_cache_key == "490_1628323817"
         assert items[2].file_name == "shared_3.jpg"
         assert items[2].thumbnail_cache_key == "96_1628323786"
+
+    @pytest.mark.asyncio
+    async def test_file_station(self, dsm_7):
+        """Test File Station."""
+        assert await dsm_7.login()
+        assert dsm_7.file
+
+        folders = await dsm_7.file.get_shared_folders()
+
+        assert folders
+        assert len(folders) == 2
+
+        assert folders[0].name == "backup"
+        assert folders[0].path == "/backup"
+        assert folders[0].is_dir is True
+        assert folders[0].additional.mount_point_type == ""
+        assert folders[0].additional.owner.gid == 0
+        assert folders[0].additional.owner.group == "root"
+        assert folders[0].additional.owner.uid == 0
+        assert folders[0].additional.owner.user == "root"
+        assert isinstance(folders[0].additional.perm.acl, dict)
+        assert isinstance(folders[0].additional.perm.adv_right, dict)
+        assert folders[0].additional.perm.acl_enable is True
+        assert folders[0].additional.perm.is_acl_mode is True
+        assert folders[0].additional.perm.is_share_readonly is False
+        assert folders[0].additional.perm.posix == 777
+        assert folders[0].additional.perm.share_right == "RW"
+        assert folders[0].additional.volume_status.freespace == 1553335107584
+        assert folders[0].additional.volume_status.totalspace == 3821146505216
+        assert folders[0].additional.volume_status.readonly is False
+
+        assert folders[1].name == "home"
+        assert folders[1].path == "/home"
+        assert folders[1].is_dir is True
+        assert folders[1].additional.mount_point_type == ""
+        assert folders[1].additional.owner.gid == 100
+        assert folders[1].additional.owner.group == "users"
+        assert folders[1].additional.owner.uid == 1046
+        assert folders[1].additional.owner.user == "hass"
+        assert isinstance(folders[1].additional.perm.acl, dict)
+        assert isinstance(folders[1].additional.perm.adv_right, dict)
+        assert folders[1].additional.perm.acl_enable is True
+        assert folders[1].additional.perm.is_acl_mode is True
+        assert folders[1].additional.perm.is_share_readonly is False
+        assert folders[1].additional.perm.posix == 777
+        assert folders[1].additional.perm.share_right == "RW"
+        assert folders[1].additional.volume_status.freespace == 1553335107584
+        assert folders[1].additional.volume_status.totalspace == 3821146505216
+        assert folders[1].additional.volume_status.readonly is False
+
+        files = await dsm_7.file.get_files("/home")
+
+        assert files
+        assert len(files) == 2
+
+        assert files[0].name == "Photos"
+        assert files[0].path == "/home/Photos"
+        assert files[0].is_dir is True
+        assert files[0].additional.mount_point_type == ""
+        assert files[0].additional.owner.gid == 105733
+        assert files[0].additional.owner.group == "SynologyPhotos"
+        assert files[0].additional.owner.uid == 1046
+        assert files[0].additional.owner.user == "hass"
+        assert isinstance(files[0].additional.perm.acl, dict)
+        assert files[0].additional.perm.is_acl_mode is True
+        assert files[0].additional.perm.posix == 711
+        assert files[0].additional.real_path == "/volume1/homes/hass/Photos"
+        assert files[0].additional.size == 50
+        assert files[0].additional.time.atime == 1735700476
+        assert files[0].additional.time.ctime == 1723653464
+        assert files[0].additional.time.crtime == 1723653032
+        assert files[0].additional.time.mtime == 1723653464
+        assert files[0].additional.type == ""
+
+        assert files[1].name == "3e57d06c.tar"
+        assert files[1].path == "/home/3e57d06c.tar"
+        assert files[1].is_dir is False
+        assert files[1].additional.mount_point_type == ""
+        assert files[1].additional.owner.gid == 100
+        assert files[1].additional.owner.group == "users"
+        assert files[1].additional.owner.uid == 1046
+        assert files[1].additional.owner.user == "hass"
+        assert isinstance(files[1].additional.perm.acl, dict)
+        assert files[1].additional.perm.is_acl_mode is True
+        assert files[1].additional.perm.posix == 711
+        assert files[1].additional.real_path == "/volume1/homes/hass/3e57d06c.tar"
+        assert files[1].additional.size == 1660753920
+        assert files[1].additional.time.atime == 1736105132
+        assert files[1].additional.time.ctime == 1736105132
+        assert files[1].additional.time.crtime == 1736105128
+        assert files[1].additional.time.mtime == 1736105132
+        assert files[1].additional.type == "TAR"
+
+    @pytest.mark.asyncio
+    async def test_virtual_machine_manager(self, dsm_7):
+        """Test vmm."""
+        assert await dsm_7.login()
+        assert dsm_7.virtual_machine_manager
+
+        await dsm_7.virtual_machine_manager.update()
+        guests = dsm_7.virtual_machine_manager.get_all_guests()
+
+        assert guests
+        assert len(guests) == 2
+
+        assert guests[0].autorun is False
+        assert guests[0].description == "vDSM test"
+        assert guests[0].guest_id == "a39d0628-380e-42f8-8cb6-a00d6b930fa0"
+        assert guests[0].name == "vdsm"
+        assert guests[0].status == "shutdown"
+        assert guests[0].host_cpu_usage == 0
+        assert guests[0].host_ram_usage == 0
+        assert guests[0].vcpu_num == 1
+        assert guests[0].vram_size == 1048576
+
+        assert guests[1].autorun is True
+        assert guests[1].description == ""
+        assert guests[1].guest_id == "2b4ec8c8-2bec-4daa-b36d-1a47b639254f"
+        assert guests[1].name == "lnx_test"
+        assert guests[1].status == "running"
+        assert guests[1].host_cpu_usage == 25
+        assert guests[1].host_ram_usage == 1169544
+        assert guests[1].vcpu_num == 1
+        assert guests[1].vram_size == 1048576
